<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://lalokalabs.co
 * @since             1.0.0
 * @package           Getotp
 *
 * @wordpress-plugin
 * Plugin Name:       GetOTP OTP Verification
 * Plugin URI:        https://getotp.dev
 * Description:       Email OTP Verification for login form. Implement 2FA Login. Powered by GetOTP.
 * Version:           1.2.1
 * Author:            LaLoka Labs
 * Author URI:        https://lalokalabs.co
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       getotp
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GETOTP_VERSION', '1.2.1' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-getotp-activator.php
 */
function activate_getotp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-getotp-activator.php';
	Getotp_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-getotp-deactivator.php
 */
function deactivate_getotp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-getotp-deactivator.php';
	Getotp_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_getotp' );
register_deactivation_hook( __FILE__, 'deactivate_getotp' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-getotp.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_getotp() {

	$plugin = new Getotp();
	$plugin->run();

}
run_getotp();
